# Architecture Decisions
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/architecture-decisions#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/architecture-decisions#benefits)
  * [Creating an Architecture Decision](https://help.sap.com/docs/leanix/ea/architecture-decisions#creating-an-architecture-decision)
  * [Managing Architecture Decisions](https://help.sap.com/docs/leanix/ea/architecture-decisions#managing-architecture-decisions)
  * [Statuses](https://help.sap.com/docs/leanix/ea/architecture-decisions#statuses)
  * [Identifiers](https://help.sap.com/docs/leanix/ea/architecture-decisions#identifiers)
  * [Diagrams in Architecture Decisions](https://help.sap.com/docs/leanix/ea/architecture-decisions#diagrams-in-architecture-decisions)
  * [Architecture Decisions on Fact Sheets](https://help.sap.com/docs/leanix/ea/architecture-decisions#architecture-decisions-on-fact-sheets)
  * [Permissions](https://help.sap.com/docs/leanix/ea/architecture-decisions#permissions)


Document and manage enterprise architecture decisions directly within SAP LeanIX, keeping all architecture-related information in one place.
